
.. code:: ipython3

    import malaya

.. code:: ipython3

    malaya.word2num.word2num('dua belas')




.. parsed-literal::

    12



.. code:: ipython3

    malaya.word2num.word2num('kesebelas')




.. parsed-literal::

    11



.. code:: ipython3

    malaya.word2num.word2num('kesebelas')




.. parsed-literal::

    11



.. code:: ipython3

    malaya.word2num.word2num('negatif kesebelas')




.. parsed-literal::

    -11



.. code:: ipython3

    malaya.word2num.word2num('seratus dua puluh tiga juta empat ratus lima puluh enam ribu tujuh ratus lapan puluh sembilan')




.. parsed-literal::

    123456789



.. code:: ipython3

    malaya.word2num.word2num('negatif seratus dua puluh tiga juta empat ratus lima puluh enam ribu tujuh ratus lapan puluh sembilan')




.. parsed-literal::

    -123456789



.. code:: ipython3

    malaya.word2num.word2num('negatif satu juta dua ratus tiga puluh empat ribu lima ratus enam puluh tujuh perpuluhan lapan sembilan')




.. parsed-literal::

    -1234567.89


